# Changelog

## 0.8.0 (2025-07-01)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.7.0...v0.8.0)

### Features

* **api:** manual updates ([ef4cd2c](https://github.com/premAI-io/prem-py-sdk/commit/ef4cd2c826fe8d74eb87efc4b3efbe2d398fa856))

## 0.7.0 (2025-07-01)

Full Changelog: [v0.5.0...v0.7.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.5.0...v0.7.0)

### Features

* **api:** api update ([8cf9df5](https://github.com/premAI-io/prem-py-sdk/commit/8cf9df5b620a1985428395a474caedf10643a9c4))

## 0.5.0 (2025-07-01)

Full Changelog: [v0.4.4...v0.5.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.4...v0.5.0)

### Features

* **api:** api update ([3a3815f](https://github.com/premAI-io/prem-py-sdk/commit/3a3815f059537cca536698dc12fa274d6108d684))
* **client:** add support for aiohttp ([4485537](https://github.com/premAI-io/prem-py-sdk/commit/4485537c514bd172a389a5db7057114c6fa56d60))


### Bug Fixes

* **ci:** correct conditional ([d48634d](https://github.com/premAI-io/prem-py-sdk/commit/d48634de614b3bb559c74895a0983c5ba1c5e7de))
* **ci:** release-doctor — report correct token name ([ba48bbe](https://github.com/premAI-io/prem-py-sdk/commit/ba48bbe0f25ffa5c125c7058bf02413d8e73c0a3))


### Chores

* **ci:** only run for pushes and fork pull requests ([fee01c6](https://github.com/premAI-io/prem-py-sdk/commit/fee01c6e5e919c831f19235fd4a4a4cffd84cc2e))
* **tests:** skip some failing tests on the latest python versions ([414cb9c](https://github.com/premAI-io/prem-py-sdk/commit/414cb9c72427bb6636888c14687a6f1d83be689c))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([847aa47](https://github.com/premAI-io/prem-py-sdk/commit/847aa47046f53ebeb53081268d215f2f22c460c4))

## 0.4.4 (2025-06-18)

Full Changelog: [v0.4.3...v0.4.4](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.3...v0.4.4)

### Bug Fixes

* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([5e1737b](https://github.com/premAI-io/prem-py-sdk/commit/5e1737b22939aa55341d81f0fcc4d5001403cab5))


### Chores

* **ci:** enable for pull requests ([2cf7744](https://github.com/premAI-io/prem-py-sdk/commit/2cf77447fd943ce5a483bd09a4a2838d13f15ed0))
* **readme:** update badges ([08872b9](https://github.com/premAI-io/prem-py-sdk/commit/08872b9fd473155015e9a6513d9412e57b60141f))

## 0.4.3 (2025-06-17)

Full Changelog: [v0.4.2...v0.4.3](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.2...v0.4.3)

### Chores

* **internal:** update conftest.py ([0e29404](https://github.com/premAI-io/prem-py-sdk/commit/0e2940456bee5c1c8a5aaa2de3effb99681447cc))
* **tests:** add tests for httpx client instantiation & proxies ([dfa6bc3](https://github.com/premAI-io/prem-py-sdk/commit/dfa6bc368ebf2202af576b74133ee627b20c94f3))

## 0.4.2 (2025-06-13)

Full Changelog: [v0.4.1...v0.4.2](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.1...v0.4.2)

### Bug Fixes

* **client:** correctly parse binary response | stream ([2ae4daf](https://github.com/premAI-io/prem-py-sdk/commit/2ae4dafcbf83a20b07a6299112c4ad20960ee90b))


### Chores

* **tests:** run tests in parallel ([92be66f](https://github.com/premAI-io/prem-py-sdk/commit/92be66f7ca6979dc7d21b99ba39c758b2ad07f3c))

## 0.4.1 (2025-06-10)

Full Changelog: [v0.0.2...v0.4.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.0.2...v0.4.1)

### Bug Fixes

* trigger release ([7f27fce](https://github.com/premAI-io/prem-py-sdk/commit/7f27fcec2259676ab3554b9c54814d49651ce67f))

## 0.0.2 (2025-06-03)

Full Changelog: [v1.2.0...v0.0.2](https://github.com/premAI-io/prem-py-sdk/compare/v1.2.0...v0.0.2)

### Features

* **client:** add follow_redirects request option ([fa4bc07](https://github.com/premAI-io/prem-py-sdk/commit/fa4bc070a8346b36bf7f615847ff80f869dc1be3))


### Chores

* **docs:** remove reference to rye shell ([976a220](https://github.com/premAI-io/prem-py-sdk/commit/976a220a2e8ef966fce0e77129d44a5773e11047))
